@@ -1,5 +1,5 @@
 import pickle
-import codecs
+import base64
 import logging
 import datetime
 import zlib
@@ -57,7 +57,7 @@ class JobFuncDef:
 
     def dump(self) -> str:
         """Dump the job function definition to a base64 string"""
-        return codecs.encode(zlib.compress(pickle.dumps(self)), "base64").decode()
+        return base64.urlsafe_b64encode(zlib.compress(pickle.dumps(self))).decode()
 
     def execute(self):
         """Execute the job function"""
@@ -69,5 +69,5 @@ class JobFuncDef:
     @staticmethod
     def load(s: str) -> 'JobFuncDef':
         """Load the job function definition from a base64 string"""
-        return pickle.loads(zlib.decompress(codecs.decode(s.encode(), "base64")))
+        return pickle.loads(zlib.decompress(base64.urlsafe_b64decode(s.encode())))
 
